News
====

* **29.09.2025** Version 2025.3 released (efficient region-only connectivity
  updates, fixed Field.set_dofs() for nonzero arrays, etc.), see :ref:`release
  notes <2025.2-2025.3>`.

* **26.06.2025** Version 2025.2 released (NumPy 2.0 compatibility, line search
  variants of the Newton solver for nonlinear problems, new large deformation
  exponential fibres term with smooth response, etc.), see :ref:`release notes
  <2025.1-2025.2>`.

* **26.03.2025** Version 2025.1 released (improved block preconditioning
  support in PETSc-based linear solvers, user functions for assembling and
  linear system scaling, pypardiso based linear solver, general hyperelastic
  term for the UL formulation, speed-up of sparse matrix graph allocation and
  assembling of matrices with many nonzeros in a row, etc.), see :ref:`release
  notes <2024.4-2025.1>`.

* **29.12.2024** Version 2024.4 released (MUMPS solver interface moved to new
  mumpspy package, python-mumps support, new contact term based on IPC toolkit,
  etc.), see :ref:`release notes <2024.3-2024.4>`.

* **30.09.2024** Version 2024.3 released (updated installation instructions,
  new Stokes traction term, etc.), see :ref:`release notes <2024.2-2024.3>`.

For historians: see :ref:`archived_news`.
